@@ -5,7 +5,7 @@ Exports public API for FraiseQL framework.
 
 # Core imports
 from .cqrs import CQRSExecutor, CQRSRepository
-from .decorators import field, query
+from .decorators import connection, field, query
 from .fields import fraise_field
 from .gql.schema_builder import build_fraiseql_schema
 from .mutations.decorators import failure, result, success
@@ -19,8 +19,10 @@ from .mutations.mutation_decorator import mutation
 from .optimization.decorators import dataloader_field
 from .subscriptions import subscription
 from .types import fraise_input, fraise_type
+from .types.common import MutationResultBase
 from .types.definitions import UNSET
 from .types.enum import fraise_enum
+from .types.errors import Error
 from .types.generic import (
     Connection,
     Edge,
@@ -71,7 +73,7 @@ except ImportError:
     Auth0Config = None
     Auth0Provider = None
 
-__version__ = "0.1.5"
+__version__ = "0.7.1"
 
 __all__ = [
     "ALWAYS_DATA_CONFIG",
@@ -88,12 +90,15 @@ __all__ = [
     "Date",
     "Edge",
     "EmailAddress",
+    "Error",
     "FraiseQLConfig",
     "MutationErrorConfig",
+    "MutationResultBase",
     "PageInfo",
     "PaginatedResponse",
     "UserContext",
     "build_fraiseql_schema",
+    "connection",
     "create_connection",
     "create_fraiseql_app",
     "dataloader_field",
